# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_friends.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_friends.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(steammessages_clientserver_friends.proto\x1a\x18steammessages_base.proto\"\x8a\x01\n\x13\x43MsgClientFriendMsg\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\x12 \n\x18rtime32_server_timestamp\x18\x04 \x01(\x07\x12\x16\n\x0e\x65\x63ho_to_sender\x18\x05 \x01(\x08\"\x9d\x01\n\x1b\x43MsgClientFriendMsgIncoming\x12\x14\n\x0csteamid_from\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x1c\n\x14\x66rom_limited_account\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\x0c\x12 \n\x18rtime32_server_timestamp\x18\x05 \x01(\x07\"R\n\x13\x43MsgClientAddFriend\x12\x16\n\x0esteamid_to_add\x18\x01 \x01(\x06\x12#\n\x1b\x61\x63\x63ountname_or_email_to_add\x18\x02 \x01(\t\"e\n\x1b\x43MsgClientAddFriendResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0esteam_id_added\x18\x02 \x01(\x06\x12\x1a\n\x12persona_name_added\x18\x03 \x01(\t\"*\n\x16\x43MsgClientRemoveFriend\x12\x10\n\x08\x66riendid\x18\x01 \x01(\x06\"6\n\x14\x43MsgClientHideFriend\x12\x10\n\x08\x66riendid\x18\x01 \x01(\x06\x12\x0c\n\x04hide\x18\x02 \x01(\x08\"\xea\x01\n\x15\x43MsgClientFriendsList\x12\x14\n\x0c\x62incremental\x18\x01 \x01(\x08\x12.\n\x07\x66riends\x18\x02 \x03(\x0b\x32\x1d.CMsgClientFriendsList.Friend\x12\x18\n\x10max_friend_count\x18\x03 \x01(\r\x12\x1b\n\x13\x61\x63tive_friend_count\x18\x04 \x01(\r\x12\x19\n\x11\x66riends_limit_hit\x18\x05 \x01(\x08\x1a\x39\n\x06\x46riend\x12\x12\n\nulfriendid\x18\x01 \x01(\x06\x12\x1b\n\x13\x65\x66riendrelationship\x18\x02 \x01(\r\"\xc5\x02\n\x1b\x43MsgClientFriendsGroupsList\x12\x10\n\x08\x62removal\x18\x01 \x01(\x08\x12\x14\n\x0c\x62incremental\x18\x02 \x01(\x08\x12>\n\x0c\x66riendGroups\x18\x03 \x03(\x0b\x32(.CMsgClientFriendsGroupsList.FriendGroup\x12H\n\x0bmemberships\x18\x04 \x03(\x0b\x32\x33.CMsgClientFriendsGroupsList.FriendGroupsMembership\x1a\x35\n\x0b\x46riendGroup\x12\x10\n\x08nGroupID\x18\x01 \x01(\x05\x12\x14\n\x0cstrGroupName\x18\x02 \x01(\t\x1a=\n\x16\x46riendGroupsMembership\x12\x11\n\tulSteamID\x18\x01 \x01(\x06\x12\x10\n\x08nGroupID\x18\x02 \x01(\x05\"\xba\x01\n\x1c\x43MsgClientPlayerNicknameList\x12\x0f\n\x07removal\x18\x01 \x01(\x08\x12\x13\n\x0bincremental\x18\x02 \x01(\x08\x12?\n\tnicknames\x18\x03 \x03(\x0b\x32,.CMsgClientPlayerNicknameList.PlayerNickname\x1a\x33\n\x0ePlayerNickname\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08nickname\x18\x03 \x01(\t\"@\n\x1b\x43MsgClientSetPlayerNickname\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08nickname\x18\x02 \x01(\t\"6\n#CMsgClientSetPlayerNicknameResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"O\n\x1b\x43MsgClientRequestFriendData\x12\x1f\n\x17persona_state_requested\x18\x01 \x01(\r\x12\x0f\n\x07\x66riends\x18\x02 \x03(\x06\"\xef\x01\n\x16\x43MsgClientChangeStatus\x12\x15\n\rpersona_state\x18\x01 \x01(\r\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\x12\x1e\n\x16is_auto_generated_name\x18\x03 \x01(\x08\x12\x15\n\rhigh_priority\x18\x04 \x01(\x08\x12\x1b\n\x13persona_set_by_user\x18\x05 \x01(\x08\x12\x1e\n\x13persona_state_flags\x18\x06 \x01(\r:\x01\x30\x12\x1d\n\x15need_persona_response\x18\x07 \x01(\x08\x12\x16\n\x0eis_client_idle\x18\x08 \x01(\x08\"@\n\x19\x43MsgPersonaChangeResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\"\xa0\x08\n\x16\x43MsgClientPersonaState\x12\x14\n\x0cstatus_flags\x18\x01 \x01(\r\x12/\n\x07\x66riends\x18\x02 \x03(\x0b\x32\x1e.CMsgClientPersonaState.Friend\x1a\xbe\x07\n\x06\x46riend\x12\x10\n\x08\x66riendid\x18\x01 \x01(\x06\x12\x15\n\rpersona_state\x18\x02 \x01(\r\x12\x1a\n\x12game_played_app_id\x18\x03 \x01(\r\x12\x16\n\x0egame_server_ip\x18\x04 \x01(\r\x12\x18\n\x10game_server_port\x18\x05 \x01(\r\x12\x1b\n\x13persona_state_flags\x18\x06 \x01(\r\x12 \n\x18online_session_instances\x18\x07 \x01(\r\x12\x1b\n\x13persona_set_by_user\x18\n \x01(\x08\x12\x13\n\x0bplayer_name\x18\x0f \x01(\t\x12\x12\n\nquery_port\x18\x14 \x01(\r\x12\x16\n\x0esteamid_source\x18\x19 \x01(\x06\x12\x13\n\x0b\x61vatar_hash\x18\x1f \x01(\x0c\x12\x13\n\x0blast_logoff\x18- \x01(\r\x12\x12\n\nlast_logon\x18. \x01(\r\x12\x18\n\x10last_seen_online\x18/ \x01(\r\x12\x11\n\tclan_rank\x18\x32 \x01(\r\x12\x11\n\tgame_name\x18\x37 \x01(\t\x12\x0e\n\x06gameid\x18\x38 \x01(\x06\x12\x16\n\x0egame_data_blob\x18< \x01(\x0c\x12:\n\tclan_data\x18@ \x01(\x0b\x32\'.CMsgClientPersonaState.Friend.ClanData\x12\x10\n\x08\x63lan_tag\x18\x41 \x01(\t\x12\x38\n\rrich_presence\x18G \x03(\x0b\x32!.CMsgClientPersonaState.Friend.KV\x12\x14\n\x0c\x62roadcast_id\x18H \x01(\x06\x12\x15\n\rgame_lobby_id\x18I \x01(\x06\x12$\n\x1cwatching_broadcast_accountid\x18J \x01(\r\x12 \n\x18watching_broadcast_appid\x18K \x01(\r\x12\"\n\x1awatching_broadcast_viewers\x18L \x01(\r\x12 \n\x18watching_broadcast_title\x18M \x01(\t\x12\x1b\n\x13is_community_banned\x18N \x01(\x08\x12\"\n\x1aplayer_name_pending_review\x18O \x01(\x08\x12\x1d\n\x15\x61vatar_pending_review\x18P \x01(\x08\x1a\x35\n\x08\x43lanData\x12\x12\n\nogg_app_id\x18\x01 \x01(\r\x12\x15\n\rchat_group_id\x18\x02 \x01(\x04\x1a \n\x02KV\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"5\n\x1b\x43MsgClientFriendProfileInfo\x12\x16\n\x0esteamid_friend\x18\x01 \x01(\x06\"\xda\x01\n#CMsgClientFriendProfileInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0esteamid_friend\x18\x02 \x01(\x06\x12\x14\n\x0ctime_created\x18\x03 \x01(\r\x12\x11\n\treal_name\x18\x04 \x01(\t\x12\x11\n\tcity_name\x18\x05 \x01(\t\x12\x12\n\nstate_name\x18\x06 \x01(\t\x12\x14\n\x0c\x63ountry_name\x18\x07 \x01(\t\x12\x10\n\x08headline\x18\x08 \x01(\t\x12\x0f\n\x07summary\x18\t \x01(\t\"[\n\x1c\x43MsgClientCreateFriendsGroup\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tgroupname\x18\x02 \x01(\t\x12\x17\n\x0fsteamid_friends\x18\x03 \x03(\x06\"H\n$CMsgClientCreateFriendsGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\x12\x0f\n\x07groupid\x18\x02 \x01(\x05\"@\n\x1c\x43MsgClientDeleteFriendsGroup\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07groupid\x18\x02 \x01(\x05\"7\n$CMsgClientDeleteFriendsGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"\x82\x01\n\x1c\x43MsgClientManageFriendsGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\x05\x12\x11\n\tgroupname\x18\x02 \x01(\t\x12\x1d\n\x15steamid_friends_added\x18\x03 \x03(\x06\x12\x1f\n\x17steamid_friends_removed\x18\x04 \x03(\x06\"7\n$CMsgClientManageFriendsGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"B\n\x1a\x43MsgClientAddFriendToGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\x05\x12\x13\n\x0bsteamiduser\x18\x02 \x01(\x06\"5\n\"CMsgClientAddFriendToGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"G\n\x1f\x43MsgClientRemoveFriendFromGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\x05\x12\x13\n\x0bsteamiduser\x18\x02 \x01(\x06\":\n\'CMsgClientRemoveFriendFromGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"\x1b\n\x19\x43MsgClientGetEmoticonList\"\x87\x04\n\x16\x43MsgClientEmoticonList\x12\x33\n\temoticons\x18\x01 \x03(\x0b\x32 .CMsgClientEmoticonList.Emoticon\x12\x31\n\x08stickers\x18\x02 \x03(\x0b\x32\x1f.CMsgClientEmoticonList.Sticker\x12/\n\x07\x65\x66\x66\x65\x63ts\x18\x03 \x03(\x0b\x32\x1e.CMsgClientEmoticonList.Effect\x1ax\n\x08\x45moticon\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x16\n\x0etime_last_used\x18\x03 \x01(\r\x12\x11\n\tuse_count\x18\x04 \x01(\r\x12\x15\n\rtime_received\x18\x05 \x01(\r\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\x1aw\n\x07Sticker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x15\n\rtime_received\x18\x03 \x01(\r\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x16\n\x0etime_last_used\x18\x05 \x01(\r\x12\x11\n\tuse_count\x18\x06 \x01(\r\x1a\x61\n\x06\x45\x66\x66\x65\x63t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x15\n\rtime_received\x18\x03 \x01(\r\x12\x14\n\x0cinfinite_use\x18\x04 \x01(\x08\x12\r\n\x05\x61ppid\x18\x05 \x01(\rB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTFRIENDMSG = _descriptor.Descriptor(
  name='CMsgClientFriendMsg',
  full_name='CMsgClientFriendMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientFriendMsg.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_entry_type', full_name='CMsgClientFriendMsg.chat_entry_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgClientFriendMsg.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_server_timestamp', full_name='CMsgClientFriendMsg.rtime32_server_timestamp', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo_to_sender', full_name='CMsgClientFriendMsg.echo_to_sender', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=209,
)


_CMSGCLIENTFRIENDMSGINCOMING = _descriptor.Descriptor(
  name='CMsgClientFriendMsgIncoming',
  full_name='CMsgClientFriendMsgIncoming',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_from', full_name='CMsgClientFriendMsgIncoming.steamid_from', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_entry_type', full_name='CMsgClientFriendMsgIncoming.chat_entry_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_limited_account', full_name='CMsgClientFriendMsgIncoming.from_limited_account', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgClientFriendMsgIncoming.message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_server_timestamp', full_name='CMsgClientFriendMsgIncoming.rtime32_server_timestamp', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=369,
)


_CMSGCLIENTADDFRIEND = _descriptor.Descriptor(
  name='CMsgClientAddFriend',
  full_name='CMsgClientAddFriend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_to_add', full_name='CMsgClientAddFriend.steamid_to_add', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountname_or_email_to_add', full_name='CMsgClientAddFriend.accountname_or_email_to_add', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=453,
)


_CMSGCLIENTADDFRIENDRESPONSE = _descriptor.Descriptor(
  name='CMsgClientAddFriendResponse',
  full_name='CMsgClientAddFriendResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAddFriendResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_added', full_name='CMsgClientAddFriendResponse.steam_id_added', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name_added', full_name='CMsgClientAddFriendResponse.persona_name_added', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=556,
)


_CMSGCLIENTREMOVEFRIEND = _descriptor.Descriptor(
  name='CMsgClientRemoveFriend',
  full_name='CMsgClientRemoveFriend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendid', full_name='CMsgClientRemoveFriend.friendid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=600,
)


_CMSGCLIENTHIDEFRIEND = _descriptor.Descriptor(
  name='CMsgClientHideFriend',
  full_name='CMsgClientHideFriend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendid', full_name='CMsgClientHideFriend.friendid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide', full_name='CMsgClientHideFriend.hide', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=656,
)


_CMSGCLIENTFRIENDSLIST_FRIEND = _descriptor.Descriptor(
  name='Friend',
  full_name='CMsgClientFriendsList.Friend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ulfriendid', full_name='CMsgClientFriendsList.Friend.ulfriendid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='efriendrelationship', full_name='CMsgClientFriendsList.Friend.efriendrelationship', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=893,
)

_CMSGCLIENTFRIENDSLIST = _descriptor.Descriptor(
  name='CMsgClientFriendsList',
  full_name='CMsgClientFriendsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bincremental', full_name='CMsgClientFriendsList.bincremental', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends', full_name='CMsgClientFriendsList.friends', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_friend_count', full_name='CMsgClientFriendsList.max_friend_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_friend_count', full_name='CMsgClientFriendsList.active_friend_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_limit_hit', full_name='CMsgClientFriendsList.friends_limit_hit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTFRIENDSLIST_FRIEND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=893,
)


_CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP = _descriptor.Descriptor(
  name='FriendGroup',
  full_name='CMsgClientFriendsGroupsList.FriendGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nGroupID', full_name='CMsgClientFriendsGroupsList.FriendGroup.nGroupID', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strGroupName', full_name='CMsgClientFriendsGroupsList.FriendGroup.strGroupName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1158,
)

_CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP = _descriptor.Descriptor(
  name='FriendGroupsMembership',
  full_name='CMsgClientFriendsGroupsList.FriendGroupsMembership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ulSteamID', full_name='CMsgClientFriendsGroupsList.FriendGroupsMembership.ulSteamID', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nGroupID', full_name='CMsgClientFriendsGroupsList.FriendGroupsMembership.nGroupID', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1160,
  serialized_end=1221,
)

_CMSGCLIENTFRIENDSGROUPSLIST = _descriptor.Descriptor(
  name='CMsgClientFriendsGroupsList',
  full_name='CMsgClientFriendsGroupsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bremoval', full_name='CMsgClientFriendsGroupsList.bremoval', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bincremental', full_name='CMsgClientFriendsGroupsList.bincremental', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friendGroups', full_name='CMsgClientFriendsGroupsList.friendGroups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memberships', full_name='CMsgClientFriendsGroupsList.memberships', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP, _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=1221,
)


_CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME = _descriptor.Descriptor(
  name='PlayerNickname',
  full_name='CMsgClientPlayerNicknameList.PlayerNickname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientPlayerNicknameList.PlayerNickname.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='CMsgClientPlayerNicknameList.PlayerNickname.nickname', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1359,
  serialized_end=1410,
)

_CMSGCLIENTPLAYERNICKNAMELIST = _descriptor.Descriptor(
  name='CMsgClientPlayerNicknameList',
  full_name='CMsgClientPlayerNicknameList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='removal', full_name='CMsgClientPlayerNicknameList.removal', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='CMsgClientPlayerNicknameList.incremental', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nicknames', full_name='CMsgClientPlayerNicknameList.nicknames', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1224,
  serialized_end=1410,
)


_CMSGCLIENTSETPLAYERNICKNAME = _descriptor.Descriptor(
  name='CMsgClientSetPlayerNickname',
  full_name='CMsgClientSetPlayerNickname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientSetPlayerNickname.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='CMsgClientSetPlayerNickname.nickname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1412,
  serialized_end=1476,
)


_CMSGCLIENTSETPLAYERNICKNAMERESPONSE = _descriptor.Descriptor(
  name='CMsgClientSetPlayerNicknameResponse',
  full_name='CMsgClientSetPlayerNicknameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientSetPlayerNicknameResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1532,
)


_CMSGCLIENTREQUESTFRIENDDATA = _descriptor.Descriptor(
  name='CMsgClientRequestFriendData',
  full_name='CMsgClientRequestFriendData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona_state_requested', full_name='CMsgClientRequestFriendData.persona_state_requested', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends', full_name='CMsgClientRequestFriendData.friends', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=1613,
)


_CMSGCLIENTCHANGESTATUS = _descriptor.Descriptor(
  name='CMsgClientChangeStatus',
  full_name='CMsgClientChangeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona_state', full_name='CMsgClientChangeStatus.persona_state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgClientChangeStatus.player_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_auto_generated_name', full_name='CMsgClientChangeStatus.is_auto_generated_name', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_priority', full_name='CMsgClientChangeStatus.high_priority', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_set_by_user', full_name='CMsgClientChangeStatus.persona_set_by_user', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_state_flags', full_name='CMsgClientChangeStatus.persona_state_flags', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_persona_response', full_name='CMsgClientChangeStatus.need_persona_response', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_client_idle', full_name='CMsgClientChangeStatus.is_client_idle', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1616,
  serialized_end=1855,
)


_CMSGPERSONACHANGERESPONSE = _descriptor.Descriptor(
  name='CMsgPersonaChangeResponse',
  full_name='CMsgPersonaChangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgPersonaChangeResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgPersonaChangeResponse.player_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1921,
)


_CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA = _descriptor.Descriptor(
  name='ClanData',
  full_name='CMsgClientPersonaState.Friend.ClanData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ogg_app_id', full_name='CMsgClientPersonaState.Friend.ClanData.ogg_app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CMsgClientPersonaState.Friend.ClanData.chat_group_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2893,
  serialized_end=2946,
)

_CMSGCLIENTPERSONASTATE_FRIEND_KV = _descriptor.Descriptor(
  name='KV',
  full_name='CMsgClientPersonaState.Friend.KV',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CMsgClientPersonaState.Friend.KV.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgClientPersonaState.Friend.KV.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2948,
  serialized_end=2980,
)

_CMSGCLIENTPERSONASTATE_FRIEND = _descriptor.Descriptor(
  name='Friend',
  full_name='CMsgClientPersonaState.Friend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendid', full_name='CMsgClientPersonaState.Friend.friendid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_state', full_name='CMsgClientPersonaState.Friend.persona_state', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_played_app_id', full_name='CMsgClientPersonaState.Friend.game_played_app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_ip', full_name='CMsgClientPersonaState.Friend.game_server_ip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_server_port', full_name='CMsgClientPersonaState.Friend.game_server_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_state_flags', full_name='CMsgClientPersonaState.Friend.persona_state_flags', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_session_instances', full_name='CMsgClientPersonaState.Friend.online_session_instances', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_set_by_user', full_name='CMsgClientPersonaState.Friend.persona_set_by_user', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgClientPersonaState.Friend.player_name', index=8,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_port', full_name='CMsgClientPersonaState.Friend.query_port', index=9,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_source', full_name='CMsgClientPersonaState.Friend.steamid_source', index=10,
      number=25, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_hash', full_name='CMsgClientPersonaState.Friend.avatar_hash', index=11,
      number=31, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_logoff', full_name='CMsgClientPersonaState.Friend.last_logoff', index=12,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_logon', full_name='CMsgClientPersonaState.Friend.last_logon', index=13,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen_online', full_name='CMsgClientPersonaState.Friend.last_seen_online', index=14,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clan_rank', full_name='CMsgClientPersonaState.Friend.clan_rank', index=15,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CMsgClientPersonaState.Friend.game_name', index=16,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CMsgClientPersonaState.Friend.gameid', index=17,
      number=56, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_data_blob', full_name='CMsgClientPersonaState.Friend.game_data_blob', index=18,
      number=60, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clan_data', full_name='CMsgClientPersonaState.Friend.clan_data', index=19,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clan_tag', full_name='CMsgClientPersonaState.Friend.clan_tag', index=20,
      number=65, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rich_presence', full_name='CMsgClientPersonaState.Friend.rich_presence', index=21,
      number=71, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CMsgClientPersonaState.Friend.broadcast_id', index=22,
      number=72, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_lobby_id', full_name='CMsgClientPersonaState.Friend.game_lobby_id', index=23,
      number=73, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_accountid', full_name='CMsgClientPersonaState.Friend.watching_broadcast_accountid', index=24,
      number=74, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_appid', full_name='CMsgClientPersonaState.Friend.watching_broadcast_appid', index=25,
      number=75, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_viewers', full_name='CMsgClientPersonaState.Friend.watching_broadcast_viewers', index=26,
      number=76, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_title', full_name='CMsgClientPersonaState.Friend.watching_broadcast_title', index=27,
      number=77, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_community_banned', full_name='CMsgClientPersonaState.Friend.is_community_banned', index=28,
      number=78, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_name_pending_review', full_name='CMsgClientPersonaState.Friend.player_name_pending_review', index=29,
      number=79, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_pending_review', full_name='CMsgClientPersonaState.Friend.avatar_pending_review', index=30,
      number=80, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA, _CMSGCLIENTPERSONASTATE_FRIEND_KV, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2980,
)

_CMSGCLIENTPERSONASTATE = _descriptor.Descriptor(
  name='CMsgClientPersonaState',
  full_name='CMsgClientPersonaState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_flags', full_name='CMsgClientPersonaState.status_flags', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends', full_name='CMsgClientPersonaState.friends', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPERSONASTATE_FRIEND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1924,
  serialized_end=2980,
)


_CMSGCLIENTFRIENDPROFILEINFO = _descriptor.Descriptor(
  name='CMsgClientFriendProfileInfo',
  full_name='CMsgClientFriendProfileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_friend', full_name='CMsgClientFriendProfileInfo.steamid_friend', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2982,
  serialized_end=3035,
)


_CMSGCLIENTFRIENDPROFILEINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientFriendProfileInfoResponse',
  full_name='CMsgClientFriendProfileInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientFriendProfileInfoResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_friend', full_name='CMsgClientFriendProfileInfoResponse.steamid_friend', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgClientFriendProfileInfoResponse.time_created', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_name', full_name='CMsgClientFriendProfileInfoResponse.real_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city_name', full_name='CMsgClientFriendProfileInfoResponse.city_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_name', full_name='CMsgClientFriendProfileInfoResponse.state_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_name', full_name='CMsgClientFriendProfileInfoResponse.country_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headline', full_name='CMsgClientFriendProfileInfoResponse.headline', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='CMsgClientFriendProfileInfoResponse.summary', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3038,
  serialized_end=3256,
)


_CMSGCLIENTCREATEFRIENDSGROUP = _descriptor.Descriptor(
  name='CMsgClientCreateFriendsGroup',
  full_name='CMsgClientCreateFriendsGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientCreateFriendsGroup.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupname', full_name='CMsgClientCreateFriendsGroup.groupname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_friends', full_name='CMsgClientCreateFriendsGroup.steamid_friends', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3258,
  serialized_end=3349,
)


_CMSGCLIENTCREATEFRIENDSGROUPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientCreateFriendsGroupResponse',
  full_name='CMsgClientCreateFriendsGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientCreateFriendsGroupResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CMsgClientCreateFriendsGroupResponse.groupid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3351,
  serialized_end=3423,
)


_CMSGCLIENTDELETEFRIENDSGROUP = _descriptor.Descriptor(
  name='CMsgClientDeleteFriendsGroup',
  full_name='CMsgClientDeleteFriendsGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientDeleteFriendsGroup.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CMsgClientDeleteFriendsGroup.groupid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3425,
  serialized_end=3489,
)


_CMSGCLIENTDELETEFRIENDSGROUPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientDeleteFriendsGroupResponse',
  full_name='CMsgClientDeleteFriendsGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientDeleteFriendsGroupResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3491,
  serialized_end=3546,
)


_CMSGCLIENTMANAGEFRIENDSGROUP = _descriptor.Descriptor(
  name='CMsgClientManageFriendsGroup',
  full_name='CMsgClientManageFriendsGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CMsgClientManageFriendsGroup.groupid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupname', full_name='CMsgClientManageFriendsGroup.groupname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_friends_added', full_name='CMsgClientManageFriendsGroup.steamid_friends_added', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_friends_removed', full_name='CMsgClientManageFriendsGroup.steamid_friends_removed', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3549,
  serialized_end=3679,
)


_CMSGCLIENTMANAGEFRIENDSGROUPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientManageFriendsGroupResponse',
  full_name='CMsgClientManageFriendsGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientManageFriendsGroupResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3681,
  serialized_end=3736,
)


_CMSGCLIENTADDFRIENDTOGROUP = _descriptor.Descriptor(
  name='CMsgClientAddFriendToGroup',
  full_name='CMsgClientAddFriendToGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CMsgClientAddFriendToGroup.groupid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamiduser', full_name='CMsgClientAddFriendToGroup.steamiduser', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3738,
  serialized_end=3804,
)


_CMSGCLIENTADDFRIENDTOGROUPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientAddFriendToGroupResponse',
  full_name='CMsgClientAddFriendToGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAddFriendToGroupResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3806,
  serialized_end=3859,
)


_CMSGCLIENTREMOVEFRIENDFROMGROUP = _descriptor.Descriptor(
  name='CMsgClientRemoveFriendFromGroup',
  full_name='CMsgClientRemoveFriendFromGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CMsgClientRemoveFriendFromGroup.groupid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamiduser', full_name='CMsgClientRemoveFriendFromGroup.steamiduser', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3861,
  serialized_end=3932,
)


_CMSGCLIENTREMOVEFRIENDFROMGROUPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientRemoveFriendFromGroupResponse',
  full_name='CMsgClientRemoveFriendFromGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRemoveFriendFromGroupResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3934,
  serialized_end=3992,
)


_CMSGCLIENTGETEMOTICONLIST = _descriptor.Descriptor(
  name='CMsgClientGetEmoticonList',
  full_name='CMsgClientGetEmoticonList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3994,
  serialized_end=4021,
)


_CMSGCLIENTEMOTICONLIST_EMOTICON = _descriptor.Descriptor(
  name='Emoticon',
  full_name='CMsgClientEmoticonList.Emoticon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientEmoticonList.Emoticon.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgClientEmoticonList.Emoticon.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_used', full_name='CMsgClientEmoticonList.Emoticon.time_last_used', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_count', full_name='CMsgClientEmoticonList.Emoticon.use_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_received', full_name='CMsgClientEmoticonList.Emoticon.time_received', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientEmoticonList.Emoticon.appid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4203,
  serialized_end=4323,
)

_CMSGCLIENTEMOTICONLIST_STICKER = _descriptor.Descriptor(
  name='Sticker',
  full_name='CMsgClientEmoticonList.Sticker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientEmoticonList.Sticker.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgClientEmoticonList.Sticker.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_received', full_name='CMsgClientEmoticonList.Sticker.time_received', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientEmoticonList.Sticker.appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_used', full_name='CMsgClientEmoticonList.Sticker.time_last_used', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_count', full_name='CMsgClientEmoticonList.Sticker.use_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4325,
  serialized_end=4444,
)

_CMSGCLIENTEMOTICONLIST_EFFECT = _descriptor.Descriptor(
  name='Effect',
  full_name='CMsgClientEmoticonList.Effect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientEmoticonList.Effect.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgClientEmoticonList.Effect.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_received', full_name='CMsgClientEmoticonList.Effect.time_received', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='infinite_use', full_name='CMsgClientEmoticonList.Effect.infinite_use', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientEmoticonList.Effect.appid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4446,
  serialized_end=4543,
)

_CMSGCLIENTEMOTICONLIST = _descriptor.Descriptor(
  name='CMsgClientEmoticonList',
  full_name='CMsgClientEmoticonList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emoticons', full_name='CMsgClientEmoticonList.emoticons', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stickers', full_name='CMsgClientEmoticonList.stickers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effects', full_name='CMsgClientEmoticonList.effects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTEMOTICONLIST_EMOTICON, _CMSGCLIENTEMOTICONLIST_STICKER, _CMSGCLIENTEMOTICONLIST_EFFECT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4024,
  serialized_end=4543,
)

_CMSGCLIENTFRIENDSLIST_FRIEND.containing_type = _CMSGCLIENTFRIENDSLIST
_CMSGCLIENTFRIENDSLIST.fields_by_name['friends'].message_type = _CMSGCLIENTFRIENDSLIST_FRIEND
_CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP.containing_type = _CMSGCLIENTFRIENDSGROUPSLIST
_CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP.containing_type = _CMSGCLIENTFRIENDSGROUPSLIST
_CMSGCLIENTFRIENDSGROUPSLIST.fields_by_name['friendGroups'].message_type = _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP
_CMSGCLIENTFRIENDSGROUPSLIST.fields_by_name['memberships'].message_type = _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP
_CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME.containing_type = _CMSGCLIENTPLAYERNICKNAMELIST
_CMSGCLIENTPLAYERNICKNAMELIST.fields_by_name['nicknames'].message_type = _CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME
_CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA.containing_type = _CMSGCLIENTPERSONASTATE_FRIEND
_CMSGCLIENTPERSONASTATE_FRIEND_KV.containing_type = _CMSGCLIENTPERSONASTATE_FRIEND
_CMSGCLIENTPERSONASTATE_FRIEND.fields_by_name['clan_data'].message_type = _CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA
_CMSGCLIENTPERSONASTATE_FRIEND.fields_by_name['rich_presence'].message_type = _CMSGCLIENTPERSONASTATE_FRIEND_KV
_CMSGCLIENTPERSONASTATE_FRIEND.containing_type = _CMSGCLIENTPERSONASTATE
_CMSGCLIENTPERSONASTATE.fields_by_name['friends'].message_type = _CMSGCLIENTPERSONASTATE_FRIEND
_CMSGCLIENTEMOTICONLIST_EMOTICON.containing_type = _CMSGCLIENTEMOTICONLIST
_CMSGCLIENTEMOTICONLIST_STICKER.containing_type = _CMSGCLIENTEMOTICONLIST
_CMSGCLIENTEMOTICONLIST_EFFECT.containing_type = _CMSGCLIENTEMOTICONLIST
_CMSGCLIENTEMOTICONLIST.fields_by_name['emoticons'].message_type = _CMSGCLIENTEMOTICONLIST_EMOTICON
_CMSGCLIENTEMOTICONLIST.fields_by_name['stickers'].message_type = _CMSGCLIENTEMOTICONLIST_STICKER
_CMSGCLIENTEMOTICONLIST.fields_by_name['effects'].message_type = _CMSGCLIENTEMOTICONLIST_EFFECT
DESCRIPTOR.message_types_by_name['CMsgClientFriendMsg'] = _CMSGCLIENTFRIENDMSG
DESCRIPTOR.message_types_by_name['CMsgClientFriendMsgIncoming'] = _CMSGCLIENTFRIENDMSGINCOMING
DESCRIPTOR.message_types_by_name['CMsgClientAddFriend'] = _CMSGCLIENTADDFRIEND
DESCRIPTOR.message_types_by_name['CMsgClientAddFriendResponse'] = _CMSGCLIENTADDFRIENDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRemoveFriend'] = _CMSGCLIENTREMOVEFRIEND
DESCRIPTOR.message_types_by_name['CMsgClientHideFriend'] = _CMSGCLIENTHIDEFRIEND
DESCRIPTOR.message_types_by_name['CMsgClientFriendsList'] = _CMSGCLIENTFRIENDSLIST
DESCRIPTOR.message_types_by_name['CMsgClientFriendsGroupsList'] = _CMSGCLIENTFRIENDSGROUPSLIST
DESCRIPTOR.message_types_by_name['CMsgClientPlayerNicknameList'] = _CMSGCLIENTPLAYERNICKNAMELIST
DESCRIPTOR.message_types_by_name['CMsgClientSetPlayerNickname'] = _CMSGCLIENTSETPLAYERNICKNAME
DESCRIPTOR.message_types_by_name['CMsgClientSetPlayerNicknameResponse'] = _CMSGCLIENTSETPLAYERNICKNAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRequestFriendData'] = _CMSGCLIENTREQUESTFRIENDDATA
DESCRIPTOR.message_types_by_name['CMsgClientChangeStatus'] = _CMSGCLIENTCHANGESTATUS
DESCRIPTOR.message_types_by_name['CMsgPersonaChangeResponse'] = _CMSGPERSONACHANGERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPersonaState'] = _CMSGCLIENTPERSONASTATE
DESCRIPTOR.message_types_by_name['CMsgClientFriendProfileInfo'] = _CMSGCLIENTFRIENDPROFILEINFO
DESCRIPTOR.message_types_by_name['CMsgClientFriendProfileInfoResponse'] = _CMSGCLIENTFRIENDPROFILEINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientCreateFriendsGroup'] = _CMSGCLIENTCREATEFRIENDSGROUP
DESCRIPTOR.message_types_by_name['CMsgClientCreateFriendsGroupResponse'] = _CMSGCLIENTCREATEFRIENDSGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientDeleteFriendsGroup'] = _CMSGCLIENTDELETEFRIENDSGROUP
DESCRIPTOR.message_types_by_name['CMsgClientDeleteFriendsGroupResponse'] = _CMSGCLIENTDELETEFRIENDSGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientManageFriendsGroup'] = _CMSGCLIENTMANAGEFRIENDSGROUP
DESCRIPTOR.message_types_by_name['CMsgClientManageFriendsGroupResponse'] = _CMSGCLIENTMANAGEFRIENDSGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientAddFriendToGroup'] = _CMSGCLIENTADDFRIENDTOGROUP
DESCRIPTOR.message_types_by_name['CMsgClientAddFriendToGroupResponse'] = _CMSGCLIENTADDFRIENDTOGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRemoveFriendFromGroup'] = _CMSGCLIENTREMOVEFRIENDFROMGROUP
DESCRIPTOR.message_types_by_name['CMsgClientRemoveFriendFromGroupResponse'] = _CMSGCLIENTREMOVEFRIENDFROMGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientGetEmoticonList'] = _CMSGCLIENTGETEMOTICONLIST
DESCRIPTOR.message_types_by_name['CMsgClientEmoticonList'] = _CMSGCLIENTEMOTICONLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientFriendMsg = _reflection.GeneratedProtocolMessageType('CMsgClientFriendMsg', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTFRIENDMSG,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendMsg)
  })
_sym_db.RegisterMessage(CMsgClientFriendMsg)

CMsgClientFriendMsgIncoming = _reflection.GeneratedProtocolMessageType('CMsgClientFriendMsgIncoming', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTFRIENDMSGINCOMING,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendMsgIncoming)
  })
_sym_db.RegisterMessage(CMsgClientFriendMsgIncoming)

CMsgClientAddFriend = _reflection.GeneratedProtocolMessageType('CMsgClientAddFriend', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTADDFRIEND,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAddFriend)
  })
_sym_db.RegisterMessage(CMsgClientAddFriend)

CMsgClientAddFriendResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAddFriendResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTADDFRIENDRESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAddFriendResponse)
  })
_sym_db.RegisterMessage(CMsgClientAddFriendResponse)

CMsgClientRemoveFriend = _reflection.GeneratedProtocolMessageType('CMsgClientRemoveFriend', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREMOVEFRIEND,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRemoveFriend)
  })
_sym_db.RegisterMessage(CMsgClientRemoveFriend)

CMsgClientHideFriend = _reflection.GeneratedProtocolMessageType('CMsgClientHideFriend', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTHIDEFRIEND,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientHideFriend)
  })
_sym_db.RegisterMessage(CMsgClientHideFriend)

CMsgClientFriendsList = _reflection.GeneratedProtocolMessageType('CMsgClientFriendsList', (_message.Message,), {

  'Friend' : _reflection.GeneratedProtocolMessageType('Friend', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTFRIENDSLIST_FRIEND,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientFriendsList.Friend)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTFRIENDSLIST,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendsList)
  })
_sym_db.RegisterMessage(CMsgClientFriendsList)
_sym_db.RegisterMessage(CMsgClientFriendsList.Friend)

CMsgClientFriendsGroupsList = _reflection.GeneratedProtocolMessageType('CMsgClientFriendsGroupsList', (_message.Message,), {

  'FriendGroup' : _reflection.GeneratedProtocolMessageType('FriendGroup', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientFriendsGroupsList.FriendGroup)
    })
  ,

  'FriendGroupsMembership' : _reflection.GeneratedProtocolMessageType('FriendGroupsMembership', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientFriendsGroupsList.FriendGroupsMembership)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTFRIENDSGROUPSLIST,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendsGroupsList)
  })
_sym_db.RegisterMessage(CMsgClientFriendsGroupsList)
_sym_db.RegisterMessage(CMsgClientFriendsGroupsList.FriendGroup)
_sym_db.RegisterMessage(CMsgClientFriendsGroupsList.FriendGroupsMembership)

CMsgClientPlayerNicknameList = _reflection.GeneratedProtocolMessageType('CMsgClientPlayerNicknameList', (_message.Message,), {

  'PlayerNickname' : _reflection.GeneratedProtocolMessageType('PlayerNickname', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPlayerNicknameList.PlayerNickname)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTPLAYERNICKNAMELIST,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPlayerNicknameList)
  })
_sym_db.RegisterMessage(CMsgClientPlayerNicknameList)
_sym_db.RegisterMessage(CMsgClientPlayerNicknameList.PlayerNickname)

CMsgClientSetPlayerNickname = _reflection.GeneratedProtocolMessageType('CMsgClientSetPlayerNickname', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSETPLAYERNICKNAME,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetPlayerNickname)
  })
_sym_db.RegisterMessage(CMsgClientSetPlayerNickname)

CMsgClientSetPlayerNicknameResponse = _reflection.GeneratedProtocolMessageType('CMsgClientSetPlayerNicknameResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSETPLAYERNICKNAMERESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetPlayerNicknameResponse)
  })
_sym_db.RegisterMessage(CMsgClientSetPlayerNicknameResponse)

CMsgClientRequestFriendData = _reflection.GeneratedProtocolMessageType('CMsgClientRequestFriendData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTFRIENDDATA,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestFriendData)
  })
_sym_db.RegisterMessage(CMsgClientRequestFriendData)

CMsgClientChangeStatus = _reflection.GeneratedProtocolMessageType('CMsgClientChangeStatus', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHANGESTATUS,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientChangeStatus)
  })
_sym_db.RegisterMessage(CMsgClientChangeStatus)

CMsgPersonaChangeResponse = _reflection.GeneratedProtocolMessageType('CMsgPersonaChangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGPERSONACHANGERESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPersonaChangeResponse)
  })
_sym_db.RegisterMessage(CMsgPersonaChangeResponse)

CMsgClientPersonaState = _reflection.GeneratedProtocolMessageType('CMsgClientPersonaState', (_message.Message,), {

  'Friend' : _reflection.GeneratedProtocolMessageType('Friend', (_message.Message,), {

    'ClanData' : _reflection.GeneratedProtocolMessageType('ClanData', (_message.Message,), {
      'DESCRIPTOR' : _CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA,
      '__module__' : 'steammessages_clientserver_friends_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientPersonaState.Friend.ClanData)
      })
    ,

    'KV' : _reflection.GeneratedProtocolMessageType('KV', (_message.Message,), {
      'DESCRIPTOR' : _CMSGCLIENTPERSONASTATE_FRIEND_KV,
      '__module__' : 'steammessages_clientserver_friends_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientPersonaState.Friend.KV)
      })
    ,
    'DESCRIPTOR' : _CMSGCLIENTPERSONASTATE_FRIEND,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPersonaState.Friend)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTPERSONASTATE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPersonaState)
  })
_sym_db.RegisterMessage(CMsgClientPersonaState)
_sym_db.RegisterMessage(CMsgClientPersonaState.Friend)
_sym_db.RegisterMessage(CMsgClientPersonaState.Friend.ClanData)
_sym_db.RegisterMessage(CMsgClientPersonaState.Friend.KV)

CMsgClientFriendProfileInfo = _reflection.GeneratedProtocolMessageType('CMsgClientFriendProfileInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTFRIENDPROFILEINFO,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendProfileInfo)
  })
_sym_db.RegisterMessage(CMsgClientFriendProfileInfo)

CMsgClientFriendProfileInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientFriendProfileInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTFRIENDPROFILEINFORESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendProfileInfoResponse)
  })
_sym_db.RegisterMessage(CMsgClientFriendProfileInfoResponse)

CMsgClientCreateFriendsGroup = _reflection.GeneratedProtocolMessageType('CMsgClientCreateFriendsGroup', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCREATEFRIENDSGROUP,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCreateFriendsGroup)
  })
_sym_db.RegisterMessage(CMsgClientCreateFriendsGroup)

CMsgClientCreateFriendsGroupResponse = _reflection.GeneratedProtocolMessageType('CMsgClientCreateFriendsGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCREATEFRIENDSGROUPRESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCreateFriendsGroupResponse)
  })
_sym_db.RegisterMessage(CMsgClientCreateFriendsGroupResponse)

CMsgClientDeleteFriendsGroup = _reflection.GeneratedProtocolMessageType('CMsgClientDeleteFriendsGroup', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDELETEFRIENDSGROUP,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDeleteFriendsGroup)
  })
_sym_db.RegisterMessage(CMsgClientDeleteFriendsGroup)

CMsgClientDeleteFriendsGroupResponse = _reflection.GeneratedProtocolMessageType('CMsgClientDeleteFriendsGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDELETEFRIENDSGROUPRESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDeleteFriendsGroupResponse)
  })
_sym_db.RegisterMessage(CMsgClientDeleteFriendsGroupResponse)

CMsgClientManageFriendsGroup = _reflection.GeneratedProtocolMessageType('CMsgClientManageFriendsGroup', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMANAGEFRIENDSGROUP,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientManageFriendsGroup)
  })
_sym_db.RegisterMessage(CMsgClientManageFriendsGroup)

CMsgClientManageFriendsGroupResponse = _reflection.GeneratedProtocolMessageType('CMsgClientManageFriendsGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTMANAGEFRIENDSGROUPRESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientManageFriendsGroupResponse)
  })
_sym_db.RegisterMessage(CMsgClientManageFriendsGroupResponse)

CMsgClientAddFriendToGroup = _reflection.GeneratedProtocolMessageType('CMsgClientAddFriendToGroup', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTADDFRIENDTOGROUP,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAddFriendToGroup)
  })
_sym_db.RegisterMessage(CMsgClientAddFriendToGroup)

CMsgClientAddFriendToGroupResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAddFriendToGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTADDFRIENDTOGROUPRESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAddFriendToGroupResponse)
  })
_sym_db.RegisterMessage(CMsgClientAddFriendToGroupResponse)

CMsgClientRemoveFriendFromGroup = _reflection.GeneratedProtocolMessageType('CMsgClientRemoveFriendFromGroup', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREMOVEFRIENDFROMGROUP,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRemoveFriendFromGroup)
  })
_sym_db.RegisterMessage(CMsgClientRemoveFriendFromGroup)

CMsgClientRemoveFriendFromGroupResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRemoveFriendFromGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREMOVEFRIENDFROMGROUPRESPONSE,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRemoveFriendFromGroupResponse)
  })
_sym_db.RegisterMessage(CMsgClientRemoveFriendFromGroupResponse)

CMsgClientGetEmoticonList = _reflection.GeneratedProtocolMessageType('CMsgClientGetEmoticonList', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETEMOTICONLIST,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetEmoticonList)
  })
_sym_db.RegisterMessage(CMsgClientGetEmoticonList)

CMsgClientEmoticonList = _reflection.GeneratedProtocolMessageType('CMsgClientEmoticonList', (_message.Message,), {

  'Emoticon' : _reflection.GeneratedProtocolMessageType('Emoticon', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTEMOTICONLIST_EMOTICON,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientEmoticonList.Emoticon)
    })
  ,

  'Sticker' : _reflection.GeneratedProtocolMessageType('Sticker', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTEMOTICONLIST_STICKER,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientEmoticonList.Sticker)
    })
  ,

  'Effect' : _reflection.GeneratedProtocolMessageType('Effect', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTEMOTICONLIST_EFFECT,
    '__module__' : 'steammessages_clientserver_friends_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientEmoticonList.Effect)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTEMOTICONLIST,
  '__module__' : 'steammessages_clientserver_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientEmoticonList)
  })
_sym_db.RegisterMessage(CMsgClientEmoticonList)
_sym_db.RegisterMessage(CMsgClientEmoticonList.Emoticon)
_sym_db.RegisterMessage(CMsgClientEmoticonList.Sticker)
_sym_db.RegisterMessage(CMsgClientEmoticonList.Effect)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
